@@ -63,11 +63,11 @@ public:
 		_next = NULL;
 		_last_known = this;
 	}
-	EzArgsToken* append(EzArgsToken* a){
-		if(this){
-			last()->_next = a;
-			_last_known = a;
-			return this;
+	friend EzArgsToken* append(EzArgsToken* self, EzArgsToken* a){
+		if(self){
+			self->last()->_next = a;
+			self->_last_known = a;
+			return self;
 		} else {
 			return a;
 		}
@@ -93,10 +93,10 @@ public:
 		if(_next) _next->dump();
 	}
    //juste les params sur la mme ligne ...
-   void dump_param(){
-      if(! this) return;
-      if(_param) printf("%s ", _param);
-      if(_next) _next->dump_param();
+   friend void dump_param(EzArgsToken* self){
+      if(! self) return;
+      if(self->_param) printf("%s ", self->_param);
+      if(self->_next) dump_param(self->_next);
    }
 };
 
@@ -221,15 +221,15 @@ public:
 
 
 bool EzArgs::add_bool(const char* key, const char* man, bool* r){
-	_tokens = _tokens->append(new EzArgsTokenBool(key, man, r)); 
+	_tokens = append(_tokens, new EzArgsTokenBool(key, man, r)); 
 	return true;
 }
 bool EzArgs::add_int(const char* key, const char* par, const char* man, int* r, int dflt){
-	_tokens = _tokens->append(new EzArgsTokenInt(key, par, man, r, NULL, dflt));
+	_tokens = append(_tokens, new EzArgsTokenInt(key, par, man, r, NULL, dflt));
 	return true;
 }
 bool EzArgs::add_int(const char* key, const char* par, const char* man, int* r, bool* rset){
-	_tokens = _tokens->append(new EzArgsTokenInt(key, par, man, r, rset, 0)); 
+	_tokens = append(_tokens, new EzArgsTokenInt(key, par, man, r, rset, 0)); 
 	return true;
 }
 bool EzArgs::add_string(
@@ -239,12 +239,12 @@ bool EzArgs::add_string(
 	const char** r,
 	const char* dflt
 ){
-	_tokens = _tokens->append(new EzArgsTokenString(key, par, man, r, dflt));
+	_tokens = append(_tokens, new EzArgsTokenString(key, par, man, r, dflt));
 	return true;
 }
 	//Les extra string sont dans une liste  part !
 bool EzArgs::add_extra(const char* par, const char* man, const char** r, const char* dflt){
-	_extras = _extras->append(new EzArgsExtra(par, man, r, dflt));
+	_extras = append(_extras, new EzArgsExtra(par, man, r, dflt));
 	_nb_extras++;
 	return true;
 }
@@ -254,7 +254,7 @@ void EzArgs::usage(){
    char* tn = basename((char*)_toolname);
    printf("%s version %s\n", tn, _version);
    printf("usage: %s [options] ", tn);
-   _extras->dump_param();
+	dump_param(_extras);
    printf("| %s -help\n", tn);
 }
 
@@ -282,6 +282,7 @@ bool EzArgs::parse(int ac, const char* av[]){
 
 	//PROLOGUE: gestions des extras
 	//on les mets dans une table et dans le bon ordre ...
+	/* USELESS ...
 	EzArgsToken* extras_tab[_nb_extras];
 	int k = _nb_extras;
 	EzArgsToken* l = _extras;
@@ -289,6 +290,7 @@ bool EzArgs::parse(int ac, const char* av[]){
 		extras_tab[k] = l;
 		l = l->next();
 	}
+	*/
 
 	_argc = ac;
 	//on dcale les args et ont met
